from add_trailing_comma._main import main

if __name__ == '__main__':
    raise SystemExit(main())
